@@ -5,6 +5,9 @@ from nango.common import set_original_form_values_on_instance
 
 
 class AdminMixin:
+    class Media:
+        js = ["nango/ws.js"]
+
     def save_model(self, request, obj, form, change):
         set_original_form_values_on_instance(form=form, instance=obj)
         return super().save_model(request=request, obj=obj, form=form, change=change)
