@@ -26,7 +26,6 @@ mymodel = get_model('some_app', 'SomeModel')
 
 class Mixin:
     def get_form(self):
-        print(f"{self=} get_form")
         form = super().get_form()
         if not isinstance(form.instance, TrackableMixin):
             return form
@@ -47,7 +46,6 @@ def __getattr__(name: str) -> Any:
     original_class = getattr(edit, name)
     if not isclass(original_class):
         raise AttributeError(f"module {__name__} has no attribute {name}")
-    print(f"making nango variant of {name=}")
     return type(
         original_class.__name__,
         (
